# Esoterrible 🤔

*The Worst Code I've Ever Written*

A while ago some friends and I brainstormed some features we would include in a bad, bad,
incredibly bad esoteric programming language. I’ve had a go at implementing some of them
as a Python module and I can confidently say it’s the worst code I’ve ever written. 
[Read More](https://rachsharp.co.uk/the-worst-code/)

Esoterrible can be installed through Pip. Tested with CPython `3.6.5` and `3.7.1`

```
pip install esoterrible
```

[example_usage.py](https://github.com/rach-sharp/esoterrible/blob/master/example_usage.py)
has examples of the horrible features included.

Feel free to throw some garbage PRs onto this fire.
